@@ -1,5 +1,7 @@
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p) {
 }
+function _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps(p) {
+}
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps(p) {
 }
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps(p) {
@@ -24,6 +26,8 @@ function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
 }
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer(p) {
 }
+function _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -39,5 +43,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer };
+module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer };
 module.exports.DeprecationError = DeprecationError;
