@@ -22,10 +22,13 @@
 
   * [Default Authorization](#default-authorization)
   * [Route Authorization](#route-authorization)
-* [JWT Authorizers](#jwt-authorizers)
+  * [JWT Authorizers](#jwt-authorizers)
 
-  * [User Pool Authorizer](#user-pool-authorizer)
-* [Lambda Authorizers](#lambda-authorizers)
+    * [User Pool Authorizer](#user-pool-authorizer)
+  * [Lambda Authorizers](#lambda-authorizers)
+* [WebSocket APIs](#websocket-apis)
+
+  * [Lambda Authorizer](#lambda-authorizer)
 
 ## Introduction
 
@@ -38,7 +41,7 @@ API](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-acces
 
 Access control for Http Apis is managed by restricting which routes can be invoked via.
 
-Authorizers, and scopes can either be applied to the api, or specifically for each route.
+Authorizers and scopes can either be applied to the api, or specifically for each route.
 
 ### Default Authorization
 
@@ -113,7 +116,7 @@ api.add_routes(
 )
 ```
 
-## JWT Authorizers
+### JWT Authorizers
 
 JWT authorizers allow the use of JSON Web Tokens (JWTs) as part of [OpenID Connect](https://openid.net/specs/openid-connect-core-1_0.html) and [OAuth 2.0](https://oauth.net/2/) frameworks to allow and restrict clients from accessing HTTP APIs.
 
@@ -148,7 +151,7 @@ api.add_routes(
 )
 ```
 
-### User Pool Authorizer
+#### User Pool Authorizer
 
 User Pool Authorizer is a type of JWT Authorizer that uses a Cognito user pool and app client to control who can access your Api. After a successful authorization from the app client, the generated access token will be used as the JWT.
 
@@ -175,7 +178,7 @@ api.add_routes(
 )
 ```
 
-## Lambda Authorizers
+### Lambda Authorizers
 
 Lambda authorizers use a Lambda function to control access to your HTTP API. When a client calls your API, API Gateway invokes your Lambda function and uses the response to determine whether the client can access your API.
 
@@ -201,6 +204,37 @@ api.add_routes(
     authorizer=authorizer
 )
 ```
+
+## WebSocket APIs
+
+You can set an authorizer to your WebSocket API's `$connect` route to control access to your API.
+
+### Lambda Authorizer
+
+Lambda authorizers use a Lambda function to control access to your WebSocket API. When a client connects to your API, API Gateway invokes your Lambda function and uses the response to determine whether the client can access your API.
+
+```python
+from aws_cdk.aws_apigatewayv2_authorizers import WebSocketLambdaAuthorizer
+from aws_cdk.aws_apigatewayv2_integrations import WebSocketLambdaIntegration
+
+# This function handles your auth logic
+# auth_handler is of type Function
+
+# This function handles your WebSocket requests
+# handler is of type Function
+
+
+authorizer = WebSocketLambdaAuthorizer("Authorizer", auth_handler)
+
+integration = WebSocketLambdaIntegration("Integration", handler)
+
+apigwv2.WebSocketApi(self, "WebSocketApi",
+    connect_route_options=apigwv2.WebSocketRouteOptions(
+        integration=integration,
+        authorizer=authorizer
+    )
+)
+```
 '''
 import abc
 import builtins
@@ -812,6 +846,156 @@ class HttpUserPoolAuthorizerProps:
         )
 
 
+@jsii.implements(aws_cdk.aws_apigatewayv2.IWebSocketRouteAuthorizer)
+class WebSocketLambdaAuthorizer(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.WebSocketLambdaAuthorizer",
+):
+    '''(experimental) Authorize WebSocket Api routes via a lambda function.
+
+    :stability: experimental
+
+    Example::
+
+        from aws_cdk.aws_apigatewayv2_authorizers import WebSocketLambdaAuthorizer
+        from aws_cdk.aws_apigatewayv2_integrations import WebSocketLambdaIntegration
+        
+        # This function handles your auth logic
+        # auth_handler is of type Function
+        
+        # This function handles your WebSocket requests
+        # handler is of type Function
+        
+        
+        authorizer = WebSocketLambdaAuthorizer("Authorizer", auth_handler)
+        
+        integration = WebSocketLambdaIntegration("Integration", handler)
+        
+        apigwv2.WebSocketApi(self, "WebSocketApi",
+            connect_route_options=apigwv2.WebSocketRouteOptions(
+                integration=integration,
+                authorizer=authorizer
+            )
+        )
+    '''
+
+    def __init__(
+        self,
+        id: builtins.str,
+        handler: aws_cdk.aws_lambda.IFunction,
+        *,
+        authorizer_name: typing.Optional[builtins.str] = None,
+        identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ) -> None:
+        '''
+        :param id: -
+        :param handler: -
+        :param authorizer_name: (experimental) The name of the authorizer. Default: - same value as ``id`` passed in the constructor.
+        :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
+
+        :stability: experimental
+        '''
+        props = WebSocketLambdaAuthorizerProps(
+            authorizer_name=authorizer_name, identity_source=identity_source
+        )
+
+        jsii.create(self.__class__, self, [id, handler, props])
+
+    @jsii.member(jsii_name="bind")
+    def bind(
+        self,
+        *,
+        route: aws_cdk.aws_apigatewayv2.IWebSocketRoute,
+        scope: constructs.Construct,
+    ) -> aws_cdk.aws_apigatewayv2.WebSocketRouteAuthorizerConfig:
+        '''(experimental) (experimental) Bind this authorizer to a specified WebSocket route.
+
+        :param route: (experimental) The route to which the authorizer is being bound.
+        :param scope: (experimental) The scope for any constructs created as part of the bind.
+
+        :stability: experimental
+        '''
+        options = aws_cdk.aws_apigatewayv2.WebSocketRouteAuthorizerBindOptions(
+            route=route, scope=scope
+        )
+
+        return typing.cast(aws_cdk.aws_apigatewayv2.WebSocketRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
+
+
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.WebSocketLambdaAuthorizerProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "authorizer_name": "authorizerName",
+        "identity_source": "identitySource",
+    },
+)
+class WebSocketLambdaAuthorizerProps:
+    def __init__(
+        self,
+        *,
+        authorizer_name: typing.Optional[builtins.str] = None,
+        identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ) -> None:
+        '''(experimental) Properties to initialize WebSocketTokenAuthorizer.
+
+        :param authorizer_name: (experimental) The name of the authorizer. Default: - same value as ``id`` passed in the constructor.
+        :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
+
+        :stability: experimental
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_apigatewayv2_authorizers as apigatewayv2_authorizers
+            
+            web_socket_lambda_authorizer_props = apigatewayv2_authorizers.WebSocketLambdaAuthorizerProps(
+                authorizer_name="authorizerName",
+                identity_source=["identitySource"]
+            )
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if authorizer_name is not None:
+            self._values["authorizer_name"] = authorizer_name
+        if identity_source is not None:
+            self._values["identity_source"] = identity_source
+
+    @builtins.property
+    def authorizer_name(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The name of the authorizer.
+
+        :default: - same value as ``id`` passed in the constructor.
+
+        :stability: experimental
+        '''
+        result = self._values.get("authorizer_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def identity_source(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''(experimental) The identity source for which authorization is requested.
+
+        :default: ['$request.header.Authorization']
+
+        :stability: experimental
+        '''
+        result = self._values.get("identity_source")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "WebSocketLambdaAuthorizerProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
     "HttpJwtAuthorizer",
     "HttpJwtAuthorizerProps",
@@ -820,6 +1004,8 @@ __all__ = [
     "HttpLambdaResponseType",
     "HttpUserPoolAuthorizer",
     "HttpUserPoolAuthorizerProps",
+    "WebSocketLambdaAuthorizer",
+    "WebSocketLambdaAuthorizerProps",
 ]
 
 publication.publish()
